[![@wq/material][logo]][docs]

**@wq/material-web** provides web bindings for [@wq/material], via the [Material UI] library.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[**Components**][components]
&bull;
[Icons][icons]
&bull;
[Inputs][inputs]

[logo]: https://wq.io/images/@wq/material.svg
[docs]: https://wq.io/@wq/material
[installation]: https://wq.io/@wq/material#installation
[api]: https://wq.io/@wq/material#api
[components]: https://wq.io/components/
[icons]: https://wq.io/icons
[inputs]: https://wq.io/inputs/

[@wq/material]: https://wq.io/@wq/material
[Material UI]: https://material-ui.com/
